@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-03-17'; # DATE
-our $VERSION = '0.93'; # VERSION
+our $DATE = '2015-03-18'; # DATE
+our $VERSION = '0.94'; # VERSION
 
 use 5.010001;
 use strict;
@@ -119,7 +119,7 @@ our %copts = (
     },
 
     naked_res => {
-        getopt  => 'naked-res',
+        getopt  => 'naked-res!',
         summary => 'When outputing as JSON, strip result envelope',
         description => <<'_',
 
@@ -138,7 +138,7 @@ you want to pipe the result for more post-processing. In this case you can use
 _
         handler => sub {
             my ($go, $val, $r) = @_;
-            $r->{naked_res} = 1;
+            $r->{naked_res} = $val ? 1:0;
         },
     },
 
@@ -1073,8 +1073,10 @@ sub run {
             if $missing && @$missing;
 
         my $scd = $r->{subcommand_data};
-        $r->{args}{-cmdline} = $self if $scd->{pass_cmdline_object} //
-            $self->pass_cmdline_object;
+        if ($scd->{pass_cmdline_object} // $self->pass_cmdline_object) {
+            $r->{args}{-cmdline} = $self;
+            $r->{args}{-cmdline_r} = $r;
+        }
 
         my $meth = "run_$r->{action}";
         die [500, "Unknown action $r->{action}"] unless $self->can($meth);
@@ -1160,7 +1162,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 0.93 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-17.
+This document describes version 0.94 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-18.
 
 =head1 DESCRIPTION
 
@@ -1623,7 +1625,11 @@ Whether to pass special argument C<-cmdline> containing the cmdline object to
 function. This can be overriden using the C<pass_cmdline_object> on a
 per-subcommand basis.
 
-Passing the cmdline object can be useful, e.g. to call run_help(), etc.
+In addition to C<-cmdline>, C<-cmdline_r> will also be passed, containing the
+C<$r> per-request stash/hash (see L</"REQUEST KEYS">).
+
+Passing the cmdline object can be useful, e.g. to call run_help(), to get the
+settings of the Perinci::CmdLine, etc.
 
 =head2 program_name => str
 
